@@ -2,7 +2,8 @@
 # Copyright (c) 2015-22 Roger S. Bivand
 #
 
-
+#' @rdname read_VECT
+#' @export
 vInfo <- function(vname, layer, ignore.stderr = NULL) {
   if (get.suppressEchoCmdInFuncOption()) {
     inEchoCmd <- get.echoCmdOption()
@@ -33,6 +34,8 @@ vInfo <- function(vname, layer, ignore.stderr = NULL) {
   res
 }
 
+#' @rdname read_VECT
+#' @export
 vColumns <- function(vname, layer, ignore.stderr = NULL) {
   if (get.suppressEchoCmdInFuncOption()) {
     inEchoCmd <- get.echoCmdOption()
@@ -64,6 +67,8 @@ vColumns <- function(vname, layer, ignore.stderr = NULL) {
   res
 }
 
+#' @rdname read_VECT
+#' @export
 vDataCount <- function(vname, layer, ignore.stderr = NULL) {
   if (get.suppressEchoCmdInFuncOption()) {
     inEchoCmd <- get.echoCmdOption()
@@ -159,13 +164,19 @@ vDataCount <- function(vname, layer, ignore.stderr = NULL) {
 ## isn't always that precise ...
 #
 
+#' @rdname read_VECT
+#' @export
+#' @importFrom stats runif
+#' @importFrom utils read.table
 vect2neigh <- function(
     vname, ID = NULL, ignore.stderr = NULL, remove = TRUE,
     vname2 = NULL, units = "k") {
+
   if (get.suppressEchoCmdInFuncOption()) {
     inEchoCmd <- get.echoCmdOption()
     tull <- set.echoCmdOption(FALSE)
   }
+
   if (is.null(ignore.stderr)) {
     ignore.stderr <- get("ignore.stderr", envir = .GRASS_CACHE)
   }
@@ -173,13 +184,13 @@ vect2neigh <- function(
 
   vinfo <- vInfo(vname)
   types <- names(vinfo)[which(vinfo > 0)]
+
   if (length(grep("areas", types)) == 0) {
     stop("Vector object not of area type")
   }
 
   n <- vDataCount(vname, ignore.stderr = ignore.stderr)
 
-
   if (!is.null(ID)) {
     if (!is.character(ID)) stop("ID not character string")
     # 		cmd <- paste(paste("v.info", .addexe(), sep=""),
@@ -213,9 +224,11 @@ vect2neigh <- function(
     }
   }
   vname2_was_null <- FALSE
+
   if (is.null(vname2)) {
     pid <- as.integer(round(runif(1, 1, 1000)))
     vname2 <- paste(vname, pid, sep = "")
+
     tull <- execGRASS("g.remove",
       type = "vector", name = vname2, flags = "f",
       intern = TRUE, ignore.stderr = ignore.stderr
@@ -317,7 +330,7 @@ vect2neigh <- function(
   if (remove) {
     tull <- execGRASS("g.remove",
       name = paste(vname2, vname2a, sep = ","), type = "vector",
-      intern = TRUE, ignore.stderr = ignore.stderr
+      intern = TRUE, ignore.stderr = ignore.stderr, flags = "f"
     )
   }
 
